@@ -3,7 +3,7 @@
 
 from typing import Dict, Sequence
 
-from gpt_index.data_structs import IndexGraph, Node
+from gpt_index.data_structs.data_structs import IndexGraph, Node
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.utils import get_sorted_node_list, truncate_text
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
@@ -45,7 +45,10 @@ class GPTTreeIndexBuilder:
         text_chunks = text_splitter.split_text(document.get_text())
         doc_nodes = {
             (start_idx + i): Node(
-                text=t, index=(start_idx + i), ref_doc_id=document.get_doc_id()
+                text=t,
+                index=(start_idx + i),
+                ref_doc_id=document.get_doc_id(),
+                embedding=document.embedding,
             )
             for i, t in enumerate(text_chunks)
         }
