@@ -2,7 +2,7 @@
 
 from typing import Optional
 
-from gpt_index.data_structs import IndexGraph, Node
+from gpt_index.data_structs.data_structs import IndexGraph, Node
 from gpt_index.indices.prompt_helper import PromptHelper
 from gpt_index.indices.utils import extract_numbers_given_response, get_sorted_node_list
 from gpt_index.langchain_helpers.chain_wrapper import LLMPredictor
